# -*- coding: utf-8 -*-

"""
a couple of variable to use throughout the app
"""

default_app_config: str = "fleetpings.apps.AaFleetpingsConfig"

__version__ = "2.3.0-alpha.2"
__title__ = "Fleet Pings"
